<?php
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalAdminSuchkonfigurationTable.php');

/**
 * Class FreinetPortalAdminPage, die Administrationsseite im internen Bereich. Hier werden auch alle Wordpress spezifischen
 * Dinge registriert.
 */
class FreinetPortalAdminPage
{
    public $plugin_name;

    function __construct()
    {
        $this->plugin_name=plugin_basename(__FILE__);
    }

    function register()
    {
        add_action('admin_menu', array($this, 'add_admin_page'));
        add_filter('plugin_action_link_freinet', array($this, 'portal_settings_link'));
        add_filter("plugin_action_links_$this->plugin_name", array($this, 'portal_settings_link'));
        add_action('admin_init', array($this, 'portal_custom_settings'));
        add_action('admin_post_freinet_portal_neue_suchkonfiguration', array($this, 'neue_suchkonfiguration_speichern'));
        add_action('admin_post_freinet_portal_suchkonfiguration_entfernen', array($this, 'suchkonfigurationEntfernen'));
    }

    function portal_custom_settings()
    {
        // Instanzliste aufsetzen und nicht überschreiben, wenn der Wert schon existiert
        add_option("freinet_portal_instanz_liste", "1");
        register_setting('freinet-portal-settings-group', 'freinet_portal_portal_id');
        register_setting('freinet-portal-settings-group', 'freinet_portal_api_key');
        register_setting('freinet-portal-settings-group', 'freinet_portal_api_host');
        add_settings_field('freinet_portal_portal_id', 'PortalNummer', array($this, 'portal_portal_id'), 'freinet_portal_plugin', 'freinet-portal-api-options');
        add_settings_field('freinet_portal_api_key', 'API Key', array($this, 'portal_api_key'), 'freinet_portal_plugin', 'freinet-portal-api-options');
        add_settings_field('freinet_portal_api_host', 'API Host', array($this, 'portal_api_host'), 'freinet_portal_plugin', 'freinet-portal-api-options');
        $boolean_options=array();
        $boolean_options['type']="boolean";
        // $suchkonfigurationId=1;
        $portalSuchkonfigurationen=explode(',', get_option('freinet_portal_instanz_liste'));
        array_walk($portalSuchkonfigurationen, function ($suchkonfigurationId) use ($boolean_options)
		{
            $settingInstanzGroupValue=sprintf('freinet-portal-settings-group-instanz-%s', $suchkonfigurationId);
            foreach($this->wpOptions($suchkonfigurationId) as $matching_kategorie=>$wp_matching_kategorie)
            {
                register_setting($settingInstanzGroupValue, $wp_matching_kategorie, $boolean_options);
            }
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::projekte_auschluss_liste($suchkonfigurationId));
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::anzuzeigende_projekt_liste($suchkonfigurationId));
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::suchformular_in_ergebnisliste_anzeigen($suchkonfigurationId), $boolean_options);
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::suchformular_in_angebotsansicht_anzeigen($suchkonfigurationId), $boolean_options);
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::suchergebnis_seitenweise_anzeigen($suchkonfigurationId), $boolean_options);
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationId));
            register_setting($settingInstanzGroupValue, FreinetPortalSettings::criteria_service_endpoint_combine_criterias($suchkonfigurationId));


            // Einleitung
            add_settings_section('freinet-portal-api-options', '1) API Konfiguration', array($this, 'portal_api_config'), 'freinet_portal_plugin');

            // Auswahl der Matchingkategorien
            add_settings_section('freinet-matching-options', '1) Auswahl der Matchingkriterien im Filter', array($this, 'description_kriterien'), $settingInstanzGroupValue);
            add_settings_section('matchingcriteria_description', '', null, $settingInstanzGroupValue);
            $criteras=FreinetPortalKriterium::CRITERIAS;
            array_walk($criteras, function ($criteriaName) use ($suchkonfigurationId) {
                $this->createMatchingCriteriaSetting($suchkonfigurationId, $criteriaName);
            });

			// 2021-09-09 Neue Option zum bündeln von doppelten Matchingkriterien (Siehe #SCpapi070980 in PortalCriteriaService) im CriteriaServiceEndpoint ($combinded_kriterien)
			add_settings_field(FreinetPortalSettings::criteria_service_endpoint_combine_criterias($suchkonfigurationId), 'Doppelte Matchingkriterien bündeln<br><span style="font-size:93%; font-weight: normal">(z.B. gleiche Kriterien-Titel von verschiedenen Agenturen)</span>', array($this, 'criteria_service_endpoint_combine_criterias'), $settingInstanzGroupValue, 'freinet-matching-options', $suchkonfigurationId);

			// 2. Spezielle Filter
            add_settings_section('freinet-special-options', '2) Spezielle Filter', array($this, 'description_spezielle_filter'), $settingInstanzGroupValue);
			add_settings_field(FreinetPortalSettings::anzuzeigende_projekt_liste($suchkonfigurationId), 'Modul ›Projekte‹ - Whitelist<div style="font-size:93%; font-weight: normal;">(ProjektID´s als fester Filter; CSV)</div>', array($this, 'freinet_portal_projekt_liste'), $settingInstanzGroupValue, 'freinet-special-options', $suchkonfigurationId);
			add_filter('pre_update_option_' . FreinetPortalSettings::anzuzeigende_projekt_liste($suchkonfigurationId), array($this, 'validate_project_list_setting'), 10, 2);
			add_settings_field(FreinetPortalSettings::projekte_auschluss_liste($suchkonfigurationId), 'Modul ›Projekte‹ - Blacklist<div style="font-size:93%; font-weight: normal;">(ProjektID´s als fester Ausschluss-Filter; CSV)</div>', array($this, 'freinet_portal_projekt_ausschluss_liste'), $settingInstanzGroupValue, 'freinet-special-options', $suchkonfigurationId);
			add_filter('pre_update_option_' . FreinetPortalSettings::projekte_auschluss_liste($suchkonfigurationId), array($this, 'validate_project_list_setting'), 10, 2);

			// 3. Verhalten bei der Suche
			add_settings_section('freinet-search-options', '3) Verhalten bei der Suche, Ergebnisliste und Anzeige', null, $settingInstanzGroupValue);
            add_settings_field(FreinetPortalSettings::suchformular_in_ergebnisliste_anzeigen($suchkonfigurationId), 'Suchformular in Ergebnisliste darstellen', array($this, 'freinet_portal_suchformular_in_ergebnisliste_anzeigen'), $settingInstanzGroupValue, 'freinet-search-options', $suchkonfigurationId);
            add_settings_field(FreinetPortalSettings::suchformular_in_angebotsansicht_anzeigen($suchkonfigurationId), 'Suchformular in Angebotsansicht darstellen', array($this, 'freinet_portal_suchformular_in_angebotsansicht_anzeigen'), $settingInstanzGroupValue, 'freinet-search-options', $suchkonfigurationId);
            add_settings_field(FreinetPortalSettings::suchergebnis_seitenweise_anzeigen($suchkonfigurationId), 'Suchergebnis seitenweise darstellen', array($this, 'freinet_portal_suchergebnis_seitenweise_anzeigen'), $settingInstanzGroupValue, 'freinet-search-options', $suchkonfigurationId);
            add_settings_field(FreinetPortalSettings::freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationId), 'Wie viele Ergebnisse sollen pro Ergebnisseite angezeigt werden? (1-1000)', array($this, 'freinet_suchergebnis_seitenweise_anzahl'), $settingInstanzGroupValue, 'freinet-search-options', $suchkonfigurationId);
        });
        add_settings_section('freinet-tipps-tricks', '2) Informationen zum Plugin', array($this, 'show_tipps_tricks'), 'freinet_portal_plugin');
    }

    function validate_project_list_setting($neue_projektliste, $alte_projektliste)
    {
        if(empty($neue_projektliste))
        {
            return $neue_projektliste;
        }
        $angeforderte_projektliste=explode(',', $neue_projektliste);
        $validierte_projektliste=array_filter($angeforderte_projektliste, function ($v) {
            $projekt_nummer=intval($v);
            return $projekt_nummer>0;
        });
        if(count($validierte_projektliste)!=count($angeforderte_projektliste))
        {
            add_settings_error(FreinetPortalSettings::projekte_auschluss_liste(), "FREINET_PORTAL_ERR_001", "Die Projektausschlussliste ist keine kommaseparierte Liste von Nummern. Der Wert wird zurückgesetzt.");
            return $alte_projektliste;
        }
        return $neue_projektliste;
    }

    // Vereinheitlichung der Settings für die Kriterien
    function add_criteria_settings_field($criteria, $title)
    {
        add_settings_field(
            $criteria,
            $title,
            array($this, $criteria), // Callbackname für die aufzurufende Funktion als Konvention aus den Konstanten
            'freinet-portal-settings-group-instanz-1',
            'freinet-matching-options');
    }

    function description_spezielle_filter()
	{
		echo '<p>';
		echo 'Die ›speziellen Filter‹ sind fixe Filter, welche die Ausgabe der ehrenamtlichen Tätigkeiten grundlegend eingrenzen.';
		echo '</p>';
	}

    function description_kriterien()
    {
        $agencyID=get_option('freinet_portal_portal_id');
        $agencyAccessKey=get_option('freinet_portal_api_key');
        echo '<style>.form-table th {  width: 350px;  } </style>';
        echo '<p>';
        echo 'Bitte aktivieren Sie im folgenden die Matchingkriterien, die Sie im Filter nutzen wollen.<br>
Die Kriterien m&uuml;ssen im Template /suche/form.php eingef&uuml;gt werden.<br>
Um einen Filter in form.php einzuf&uuml;gen, nutzen Sie folgenden Befehl:<br>
<span class="code">
' . htmlspecialchars('<?=$formElements[\'arbeitsweisen\']->render() ?>') . '
</span><br><br>
';
        if(trim($agencyID . $agencyAccessKey)!='')
        {
            echo '(Hier finden Sie einige Informationen zur Agentur: <a target="_blank" href="https://freinet-online.de/query/stats.php?agencyID=' . $agencyID . '&accessKey=' . $agencyAccessKey . '">Informationen zur Agentur (json) )</a>';
        }
        echo '</p>';
    }

    function portal_api_config()
    {
        echo '<p>Geben Sie im folgenden die Authorisierungs-Codes ein.<br>
Diese haben Sie von uns per E-Mail erhalten.<br>
Der API Host lautet -sofern nicht anders angegeben- <strong>www.lachnit-software.de</strong></p>';
    }

    function show_tipps_tricks()
    {
        echo '<h4>2.1) Über das Plugin</h4>';
        echo '<p>Diese Plugin holt veröffentlichte Angebote von <a target="_blank" href="https://freinet-online.de">Freinet-Online</a> und stellt diese durchsuchbar innerhalb dieser Wordpressinstallation dar.</p>';
        echo '<p>Für Rückfragen und technischen Support wenden Sie sich bitte an <a target="_blank" href="mailto:rademacher@freinet-online.de">Jan Rademacher &lt;rademacher@freinet-online.de&gt;</a></p>';

        echo '<h4>2.2) Einfügen des Plugins in eine Wordpress-Seite</h4>';
        echo '<p>Der Platzhalter <span class="code">[freinet_portal_api_portale suchkonfiguration="1"]</span> fügt das Plugin in Ihre Seite ein.</p>';

        echo '<h4>2.3) Über die ›Suchkonfigurationen‹</h4>';
        echo '<p>';
		echo 'Mittels der ›Suchkonfigurationen‹ können Sie das Plugin auf ihren Wordpress-Seiten mehrfach verwenden und (anhand der Einstellungen in der ›Suchkonfiguration‹)<br>'.
			'verschiedene Engagement-Angebote ausgeben (z.B. auf einer Wordpress-Seite „klassische Engagements“ und auf einer anderen Seite Engagements, welche auf ein bestimmtes Projekt beschränkt sind)<br>'.
			'Suchkonfigurationen können Sie im linken Menü erzeugen, bearbeiten und entfernen.'.
			'</p>';

        echo '<h4>2.4) Modifikationen der Templates</h4>';
        echo '<p>';
        echo 'Im Unterordner suche/ finden Sie folgende Dateien:
<div class="code" style="margin-bottom: 10px;">
<table border="0" cellpadding="6" cellspacing="0">
<tr valign="top"><td>./suche/css/freinetstyle.css</td><td>CSS Datei, um das Plugin zu gestalten.<br>Hinweis: die CSS Datei arbeitet aus Lizenzgründen mit einer @Import Regel. Sie können sich den Import-Code <a target="_blank" href="https://freinet-online.de/content/css/wordpress_freinet_portal_api_portale.css">hier</a> herunterladen und direkt einfügen.</td></tr>
<tr valign="top"><td>./suche/angebot.php</td><td>Ausgabetemplate der Detailansicht eines Angebotes</td></tr>
<tr valign="top"><td>./suche/ergebnis.php</td><td>Ausgabetemplate der Ergebnisliste, wenn auf ›Suchen‹ geklickt wurde</td></tr>
<tr valign="top"><td>./suche/form.php</td><td>Ausgabetemplate für die Eingabe-Filter der Matchingkategorien</td></tr>
</table>
</div>
Wenn Sie eigene Templates erstellen möchten, erstellen Sie jeweils Kopien dieser Dateien und speichern Sie diese mit dem Zusatz _CUSTOM. (Z.B. <span class="code">form_CUSTOM.php</span>)<br>
Das Plugin wird dann diese Dateien anstatt der Originale nutzen.<br>
Dies sichert bei einem Update des Plugins Ihre Modifikationen.';
        echo '</p>';
        echo '<p>Weiterführende Anpassungen an den restlichen Dateien werden bei einem Update ggf. überschrieben. Bitte sorgen Sie in diesem Fall für ein Backup Ihrer Dateien.</p>';
        echo '<h4>2.4.1) CSS</h4>
In der freinetstyle.css wird ein CSS-Grid mit ausgeliefert, welches auf dem CSS-Framework yaml:4 basiert. Die Dokumentation dazu finden Sie hier: <a target="_blank" href="http://www.yaml.de/docs/index.html#yaml-grids">yaml.de</a>
</h4>';


        echo '<h4>2.5) ApiEndpoints</h4>';
        if(get_option('freinet_portal_portal_id')!='')
        {
            $url_kat='https://' . get_option('freinet_portal_api_host') . '/query/api/portal/v1/CriteriaServiceEndpoint.php?portalId=' . get_option('freinet_portal_portal_id') . '&accessKey=' . get_option('freinet_portal_api_key');
            $url_list='https://' . get_option('freinet_portal_api_host') . '/query/api/portal/v1/MatchingServiceEndpoint.php?limit=10&portalId=' . get_option('freinet_portal_portal_id') . '&accessKey=' . get_option('freinet_portal_api_key');
            $url_detail='https://' . get_option('freinet_portal_api_host') . '/query/api/portal/v1/OfferServiceEndpoint.php?portalId=' . get_option('freinet_portal_portal_id') . '&accessKey=' . get_option('freinet_portal_api_key') . '&offerId=12345';
            $url_detail_name='https://' . get_option('freinet_portal_api_host') . '/query/api/portal/v1/OfferServiceEndpoint.php?portalId=' . get_option('freinet_portal_portal_id') . '&accessKey=' . get_option('freinet_portal_api_key') . '&offerId=<span style="color:red">12345</span>';

            echo '<p>';
            echo 'Folgende API-Enpoints werden durch dieses Plugin angesprochen:';
            echo '
<ul style="margin: 10px; line-height: 1.5">
<li><strong>Matching-Kategorien</strong> (für die Darstellung der Filter)<br>
<span class="code"><a target="_blank" href="' . $url_kat . '">' . $url_kat . '</a></span>
</li>
<li><strong>Ergebnisliste der Angebote</strong> (für die Liste der Angebote, wenn man auf ›Suchen‹ geklickt hat)<br>
<span class="code"><a target="_blank" href="' . $url_list . '">' . $url_list . '</a></span>
</li>
<li><strong>Detailansicht eines Angebotes</strong><br>
<span class="code"><a target="_blank" href="' . $url_detail . '">' . $url_detail_name . '</a></span><br>
(Die offerId muss natürlich ersetzt werden, durch eine vorhandene AngebotsID...)
</li>
</ul>';
            echo '</p>';
        }
        else
        {
            echo '<p>- Informationen werden zu den Api-Endpoints werden erst nach Eingabe der API Konfigurationsdaten angezeigt. -</p>';
        }

        echo '<h4>2.6) Troubleshooting</h4>';
        echo '<p><strong>Es werden keine Angebote angezeigt</strong><br>
- Es kann sein, dass die Agentur noch keine Angebote veröffentlicht hat.<br>
<strong>Es werden keine Matchingkriterien angezeigt</strong><br>
- Es kann sein, dass die Agentur noch keine Angebote veröffentlicht hat.<br>
- Es kann sein, dass die Agentur die entsprechende Kategorie (z.B. globalbereiche) garnicht nutzt.<br>
&nbsp;&nbsp;(Schauen Sie in diesem Fall bitte in dem angegebenen json File (s.o), welche Kategorien die Agentur nutzt.)</p>';

        echo '<h4>2.7) Demodaten</h4>';
        echo '<p>Sofern Ihre Agentur noch keine Daten veröffentlicht hat, k&ouml;nnen Sie mit folgendes Agenturdaten bereits das Plugin testen:
<div class="code">
- PortalNummer: 8<br>
- Accesskey:  TcLKKODSz 
</div><br>
Bitte nehmen Sie zur Kenntnis, dass es sich hierbei lediglich um Testdaten handelt.<br>
(Inhaltlich k&ouml;nnen es also etwas kuriose Daten sein ;o) )</p>';
    }

    function renderSelectOrCheckBoxSetting($args)
    {
        $suchkonfigurationId=$args['suchkonfigurationId'];
        $criteriaName=$args['criteriaName'];
        $value=get_option($this->criteriaPrefix($suchkonfigurationId) . $criteriaName);
        $values[0]='Nicht nutzen';
		$values[1]='Zeige Dropdown-Feld';
		$values[2]='Zeige Checkboxen';
        if($args['criteriaName']=='angebotplzs') $values['3']='Zeige Input Text'; // 2021-09-08 Wenn angebotplz, dann soll auch ein input type="text" renderbar sein
		$values[4]='Zeige SelectCheckboxen'; // 2021-09-08
		$values[5]='Zeige CheckButton'; // 2021-09-08

        $renderer=new FreinetFormSelectBoxRenderer($values, $this->criteriaPrefix($suchkonfigurationId) . $criteriaName, "", $value);
        $renderer->disableShowAll();
        echo $renderer->render();
    }

    function freinet_portal_suchformular_in_ergebnisliste_anzeigen($suchkonfigurationId)
    {
        $this->renderBooleanSetting(FreinetPortalSettings::suchformular_in_ergebnisliste_anzeigen($suchkonfigurationId));
    }

    function freinet_portal_suchformular_in_angebotsansicht_anzeigen($suchkonfigurationId)
    {
        $this->renderBooleanSetting(FreinetPortalSettings::suchformular_in_angebotsansicht_anzeigen($suchkonfigurationId));
    }

    function freinet_portal_projekt_ausschluss_liste($suchkonfigurationId)
    {
        $setting_key=esc_attr(FreinetPortalSettings::projekte_auschluss_liste($suchkonfigurationId));
        $ausschluss_liste=esc_attr(get_option($setting_key));
        echo '<input type="text" name="' . $setting_key . '" value="' . $ausschluss_liste . '" />';
    }

    function freinet_portal_projekt_liste($suchkonfigurationId)
    {
        $setting_key=esc_attr(FreinetPortalSettings::anzuzeigende_projekt_liste($suchkonfigurationId));
        $projektliste=esc_attr(get_option($setting_key));
        echo '<input type="text" name="' . $setting_key . '" value="' . $projektliste . '" />';
    }

    function freinet_portal_suchergebnis_seitenweise_anzeigen($suchkonfigurationId)
    {
        $this->renderBooleanSetting(FreinetPortalSettings::suchergebnis_seitenweise_anzeigen($suchkonfigurationId));
    }

    // 2021-09-09
	function criteria_service_endpoint_combine_criterias($suchkonfigurationId)
	{
		$this->renderBooleanSetting(FreinetPortalSettings::criteria_service_endpoint_combine_criterias($suchkonfigurationId));
	}

    function renderBooleanSetting($setting)
    {
        $value=get_option($setting);
        if($value)
        {
            echo '<input type="checkbox" name="' . $setting . '" value="1" checked/>';
        }
        else
        {
            echo '<input type="checkbox" name="' . $setting . '" value="1"/>';
        }
    }

    function portal_api_host()
    {
        $portal_api_host=esc_attr(get_option('freinet_portal_api_host'));
        echo '<input type="text" name="freinet_portal_api_host" value="' . $portal_api_host . '" />';
    }

    function portal_api_key()
    {
        $portal_api_key=esc_attr(get_option('freinet_portal_api_key'));
        echo '<input type="text" name="freinet_portal_api_key" value="' . $portal_api_key . '" />';
    }

    function portal_portal_id()
    {
        $portal_portal_id=esc_attr(get_option('freinet_portal_portal_id'));
        echo '<input type="text" name="freinet_portal_portal_id" value="' . $portal_portal_id . '" />';
    }

    function freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationId)
    {
        $setting=FreinetPortalSettings::freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationId);
        $anzahl=esc_attr(get_option($setting));
        echo '<input type="number" name="' . $setting . '" value="' . $anzahl . '" min="1" max="1000" />';
    }

    function portal_settings_link($links)
    {
        $portal_settings_link='<a href="admin.php?page=freinet_portal_plugin">Einstellungen</a>';
        array_push($links, $portal_settings_link);
        return $links;
    }

    function add_admin_page()
    {
        add_menu_page("Freinet Konfiguration", "Freinet ›Portal‹", "manage_options", "freinet_portal_plugin", array($this, 'admin_index'));
        add_submenu_page('freinet_portal_plugin', 'Suchkonfiguration', 'Neue Suchkonfiguration', 'manage_options', 'freinet_portal_suchkonfiguration_neu', array($this, 'suchkonfiguration_index_neu'));
        add_submenu_page('freinet_portal_plugin', 'Suchkonfiguration', 'Suchkonfigurationen verwalten', 'manage_options', 'freinet_portal_suchkonfiguration', array($this, 'suchkonfiguration_index'));
    }

    function admin_index()
    {
        require_once plugin_dir_path(__FILE__) . 'admin/configuration_page.php';
    }

    function suchkonfiguration_index()
    {
        if($_GET['freinet_portal_suchkonfiguration_action']=='anpassen')
        {
            $suchkonfigurationId=$_GET['freinet_portal_suchkonfiguration'];
            if(!preg_match('/ˆ\d+$/', $suchkonfigurationId))
            {
                require_once plugin_dir_path(__FILE__) . 'admin/configuration_page_suchkonfiguration_anpassen.php';
            }
            else
            {
                wp_die('Verarbeitung abgebrochen, da die Anfrage unvollständig oder manipuliert ist.');
            }
        }
        else
        {
            $freinetSuchkonfigurationTable=new FreinetPortalAdminSuchkonfigurationTable();
            $freinetSuchkonfigurationTable->prepare_items();
            require_once plugin_dir_path(__FILE__) . 'admin/configuration_page_suchkonfiguration.php';
        }
    }

    function suchkonfiguration_index_neu()
    {
        require_once plugin_dir_path(__FILE__) . 'admin/configuration_page_suchkonfiguration_neu.php';
    }

    function neue_suchkonfiguration_speichern()
    {
        $suchkonfigurationName=$_POST['suchkonfiguration_name'];
        $validSuchkonfigurationName=preg_match('/^[a-zA-Z0-9\söÖüÜäÄß]+$/', $suchkonfigurationName);
        if(!$validSuchkonfigurationName)
        {
            wp_redirect(add_query_arg(array(
                'page' => 'freinet_portal_suchkonfiguration_neu',
                'error' => 'validation'
            ), admin_url('admin.php')));
            exit;
        }
        $instanzListeConfigValue=get_option('freinet_portal_instanz_liste');
        if(empty($instanzListeConfigValue))
        {
            update_option('freinet_portal_instanz_liste', '1');
            $this->saveOptionsForSuchkonfiguration(1, $suchkonfigurationName);
        }
        else
        {
            $instanzListe=explode(',', $instanzListeConfigValue);
            $neueInstanzId=max($instanzListe) + 1;
            array_push($instanzListe, $neueInstanzId);
            update_option('freinet_portal_instanz_liste', implode(',', $instanzListe));
            $this->saveOptionsForSuchkonfiguration($neueInstanzId, $suchkonfigurationName);


        }
        wp_redirect(add_query_arg('page', 'freinet_portal_suchkonfiguration', admin_url('admin.php')));
        exit;
    }

    function suchkonfigurationEntfernen()
    {
        $suchkonfigurationsId=$_POST['freinet_portal_suchkonfiguration_id'];
        if(empty($suchkonfigurationsId))
        {
            wp_die('Verarbeitung abgebrochen, da der Request manipuliert erscheint.');
        }
        $instanzListe=explode(',', get_option('freinet_portal_instanz_liste'));
        $neueInstanzListe=array_filter($instanzListe, function ($data) use ($suchkonfigurationsId) {
            return $data!=$suchkonfigurationsId;
        });
        $criterias=FreinetPortalKriterium::CRITERIAS;
        array_walk($criterias, function ($criteria) use ($suchkonfigurationsId) {
            delete_option(sprintf('freinet_portal_%d_matchingcriteria_use_%s', $suchkonfigurationsId, $criteria));
        });
        delete_option(FreinetPortalSettings::anzuzeigende_projekt_liste($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::projekte_auschluss_liste($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::suchformular_in_angebotsansicht_anzeigen($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::suchformular_in_ergebnisliste_anzeigen($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::suchergebnis_seitenweise_anzeigen($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::freinet_portal_angelegt_durch($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::freinet_portal_suchkonfiguration_anzeige_name($suchkonfigurationsId));
        delete_option(FreinetPortalSettings::criteria_service_endpoint_combine_criterias($suchkonfigurationsId));
        update_option('freinet_portal_instanz_liste', implode(',', $neueInstanzListe));
        wp_redirect(add_query_arg('page', 'freinet_portal_suchkonfiguration', admin_url('admin.php')));
        exit;
    }

    private function saveOptionsForSuchkonfiguration($neueInstanzId, $suchkonfigurationName)
    {
        update_option(FreinetPortalSettings::freinet_portal_angelegt_durch($neueInstanzId), wp_get_current_user()->display_name);
        update_option(FreinetPortalSettings::freinet_portal_suchkonfiguration_anzeige_name($neueInstanzId), $suchkonfigurationName);
    }

	// Für die Speicherung im AdminBereich
    private function wpOptions($suchkonfiugrationId)
    {
        $prefix=$this->criteriaPrefix($suchkonfiugrationId);
        return array(
            'angebotplzs'=>$prefix . 'angebotplzs', // 2021-09-08 +
            'arbeitsweisen'=>$prefix . 'arbeitsweisen',
            'zielgruppen'=>$prefix . 'zielgruppen',
            'ziel2gruppen'=>$prefix . 'ziel2gruppen',
            'handlungsfelder'=>$prefix . 'handlungsfelder',
            'handlungs2felder'=>$prefix . 'handlungs2felder',
            'kenntnisse'=>$prefix . 'kenntnisse',
            'globalbereiche'=>$prefix . 'globalbereiche',
            'sprachen'=>$prefix . 'sprachen',
            'stadtteile'=>$prefix . 'stadtteile',
            'umgebung'=>$prefix . 'umgebung',
            'zeitspenden'=>$prefix . 'zeitspenden',
            'sachspenden'=>$prefix . 'sachspenden',
			'mtffa1' => $prefix . 'mtffa1',
			'mtffa2' => $prefix . 'mtffa2',
			'mtffa3' => $prefix . 'mtffa3',
			'mtffa4' => $prefix . 'mtffa4',
			'mtffa5' => $prefix . 'mtffa5',
			'mtffa6' => $prefix . 'mtffa6',
			'ehrenamttyp' => $prefix . 'ehrenamttyp',
			'portalmatrix1' => $prefix . 'portalmatrix1',
			'portalmatrix2' => $prefix . 'portalmatrix2'
        );
    }

    private function criteriaPrefix($suchkonfiugrationId)
    {
        return sprintf('freinet_portal_%s_matchingcriteria_use_', $suchkonfiugrationId);
    }

    private function createMatchingCriteriaSetting($suchkonfigurationId, $criteriaName)
    {
        add_settings_field(
            $criteriaName,
			sprintf('Matchingkategorie &rsaquo;%s&lsaquo;', ucfirst($criteriaName)),
            array($this, 'renderSelectOrCheckBoxSetting'),
            sprintf('freinet-portal-settings-group-instanz-%s', $suchkonfigurationId),
            'freinet-matching-options',
            array(
                'suchkonfigurationId'=>$suchkonfigurationId,
                'criteriaName'=>$criteriaName
            )
        );
    }
}
