<?php
// Sicherheitscheck, ob diese Datei im Wordpresscontext läuft. Ansonsten wird die Verarbeitung abgebrochen.
defined('ABSPATH') or die;
require_once 'ImageTagRenderer.php';

/**
 * Class FreinetPortalAngebot
 */
class FreinetPortalAngebotListe
{
    private $angebotName;
    private $angebotsId;
    private $agenturId;
    private $agenturname;
    private $einrichtungsname;
    private $beschreibung;
    private $wertigkeit;
    private $angebotsPLZ;
    private $angebotsOrt;
    private $angebotsAvatar;
    private $angebotsTermine;
    private $angebotsAnzahlGesuche;
    private $angebotsAnzahlAktuellerVermittlungen;
    private $angebotsKontaktierbarkeit;

    public function __construct($angebotsId, $angebotName, $agenturId, $agenturname, $einrichtungsname, $beschreibung, $angebotsPLZ, $angebotsOrt, $angebotsAvatar, $angebotsTermine, $angebotsAnzahlGesuche, $angebotsAnzahlAktuellerVermittlungen, $angebotsKontaktierbarkeit)
    {
        $this->angebotsId = $angebotsId;
        $this->angebotName = $angebotName;
        $this->agenturId = $agenturId;
        $this->agenturname = $agenturname;
        $this->einrichtungsname = $einrichtungsname;
        $this->beschreibung = $beschreibung;
        $this->angebotsPLZ = $angebotsPLZ;
        $this->angebotsOrt = $angebotsOrt;
        $this->angebotsAvatar = $angebotsAvatar;
        $this->angebotsTermine = $angebotsTermine;
        $this->angebotsAnzahlGesuche = $angebotsAnzahlGesuche;
        $this->angebotsAnzahlAktuellerVermittlungen = $angebotsAnzahlAktuellerVermittlungen;
        $this->angebotsKontaktierbarkeit = $angebotsKontaktierbarkeit;
    }

    public function getAngebotName()
    {
        return $this->angebotName;
    }

    public function getAngebotsId()
    {
        return $this->angebotsId;
    }

    public function getAgenturId()
    {
        return $this->agenturId;
    }

    public function getAgenturName()
    {
        return $this->agenturname;
    }

    public function getEinrichtungname()
    {
        return $this->einrichtungsname;
    }

    public function getBeschreibung()
    {
        return $this->beschreibung;
    }

	/**
	 * Erzeugt eine gekuerzte Version der Angebotsbeschreibung
	 * @ToDo Laenge der Kurzfassung im AdminArea einstellbar machen.
	 * @param int $maxLength
	 * @return string
	 */
    public function getKurzBeschreibung($maxLength='300')
    {
		$this->beschreibung=strip_tags($this->beschreibung);
        if (strlen($this->beschreibung) >= $maxLength)
        {
            $shortendText = substr($this->beschreibung, 0, $maxLength);
            $fixed = $this->closeTags($shortendText);
            return $fixed . "...";
        }
        return $this->beschreibung;
    }

	public function getAngebotsPLZ()
	{
		return $this->angebotsPLZ;
	}

	public function getAngebotsOrt()
	{
		return $this->angebotsOrt;
	}

	public function getAngebotsTermine()
	{
		return $this->angebotsTermine;
	}

	public function getAngebotsAnzahlGesuche()
	{
		return $this->angebotsAnzahlGesuche;
	}

	public function getAngebotsAnzahlAktuellerVermittlungen()
	{
		return $this->angebotsAnzahlAktuellerVermittlungen;
	}

	public function getAngebotsKontaktierbarkeit()
	{
		return $this->angebotsKontaktierbarkeit;
	}

	/**
	 * Erzeugt den Avatar
	 * @return string
	 */
	public function getAngebotsAvatarAsHTML()
	{
		/*
		 * @ToDo Die Groesse des Avatars sollte im Adminarea waehlbar sein.
		 * Die Avatare liegen unter der URL //freinet-online.de/content/files/ds_avatar/ in verschiedenen Groessen vor
		 * avatar_h20px.jpg|.png
		 * avatar_w100px.jpg|.png
		 * avatar_w150px.jpg|.png
		 * avatar_w250px.jpg|.png
		 * avatar.jpg|.png // Achtung - Original (Groesse beachten!)
		 */
		if($this->angebotsAvatar!=''){
			$this->angebotsAvatar=str_replace('.', '_w150px.', $this->angebotsAvatar);
			return FreinetPortalImageTagRenderer::fromUrl('//freinet-online.de/content/files/ds_avatar/'.$this->angebotsAvatar);
		}
		elseif(get_option('freinet_portal_show_avatar_dummy')!=''){
			return FreinetPortalImageTagRenderer::fromUrl(get_option('freinet_portal_show_avatar_dummy'));
		}
		else
			return '';
	}

	/**
	 * anzeigeLink() in AngebotListe
	 * @param FreinetPortalSearchParams $suchParameter
	 * @return string
	 */
    public function anzeigeLink(FreinetPortalSearchParams $suchParameter)
    {
		$freinetSearchQueryArgs['freinet_portal_wp_action']='angebot_anzeigen';
		$freinetSearchQueryArgs['freinet_portal_wp_angebot_nummer']=$this->getAngebotsId();
        $umkreis=implode(',', $suchParameter->getUmkreis());
		if($umkreis>0) $freinetSearchQueryArgs['freinetSearchData[umkreis]']=$umkreis;
        foreach(FreinetPortalKriterium::CRITERIAS as $criteriaName)
        {
			// 2021-09-09 only, if value not empty
			if($suchParameter->getCriterias()[$criteriaName]!='') $freinetSearchQueryArgs[$criteriaName] = $suchParameter->getCriterias()[$criteriaName];
        }

		// @Todo schau mal, Andre, spricht an dieser Stelle etwas gegen array_filter() ?
        return add_query_arg($freinetSearchQueryArgs);
    }

    private function closeTags($html)
    {
        // Credit goes to https://gist.github.com/JayWood/348752b568ecd63ae5ce
        preg_match_all('#<([a-z]+)(?: .*)?(?<![/|/ ])>#iU', $html, $result);
        $openedtags = $result[1];
        preg_match_all('#</([a-z]+)>#iU', $html, $result);
        $closedtags = $result[1];
        $len_opened = count($openedtags);
        if (count($closedtags) == $len_opened) {
            return $html;
        }
        $openedtags = array_reverse($openedtags);
        for ($i=0; $i < $len_opened; $i++) {
            if (!in_array($openedtags[$i], $closedtags)) {
                $html .= '</'.$openedtags[$i].'>';
            } else {
                unset($closedtags[array_search($openedtags[$i], $closedtags)]);
            }
        }
		$html=str_replace('</br>', '', $html); // 2018-08-28 this function also closes <br>...
        return $html;
    }

    public function getWertigkeit()
    {
        return $this->wertigkeit;
    }

    public function setWertigkeit($wertigkeit)
    {
        $this->wertigkeit = $wertigkeit;
    }

}