<?php
// Sicherheitscheck, ob diese Datei im Wordpresscontext läuft. Ansonsten wird die Verarbeitung abgebrochen.
defined('ABSPATH') or die;

class FreinetPortalApiClient
{
    private $accessKey;
    private $portalId;
    private $host;
    private $cachedCriterias;

    // Limitgrenzen für die Suche
    const UPPER_LIMIT=1000;
    const LOWER_LIMIT=0;

    public function __construct($accessKey, $portalId, $host)
    {
        $this->accessKey=$accessKey;
        $this->portalId=$portalId;
        $this->host=$host;
    }

    /**
     * Diese Funktion gibt die XML Abfrage " $this->cachedCriterias " zu den Matchingkategorien als Array zurück
     * Das zurückgegebene Array ist folgendermaßen aufgebaut $arr[kategorie_name][ID]=Titel
	 * @param int $suchkonfigurationsid
     *
     * @return mixed
     */
    function getCriteriasAsArray($suchkonfigurationsid)
    {
        if($this->criteriasNotLoaded()) $this->getCriterias($suchkonfigurationsid);
        foreach(FreinetPortalKriterium::CRITERIAS as $value) $criteria[$value]=self::filterCriteriasFor($value);
        return $criteria;
    }

    private function filterCriteriasFor($name)
    {
        if($name=='umkreis') return $this->getUmkreise();
        return $this->xmlToArray($this->cachedCriterias->$name->kriterium);
    }

    /**
     * Diese Funktion setzt den Query zusammen UND holt die Daten via FreinetPortalSimpleHttpClient von der API ab
     * @param FreinetPortalSearchParams $params
     * @return FreinetPortalSearchResult
     * @throws ErrorException
     */
    function search(FreinetPortalSearchParams $params, $suchkonfigurationId)
    {
        if(get_option(FreinetPortalSettings::suchergebnis_seitenweise_anzeigen($suchkonfigurationId)))
        {
            $limit=esc_attr(get_option(FreinetPortalSettings::freinet_suchergebnis_seitenweise_anzahl($suchkonfigurationId)));
        }
		$umkreis=implode(",", $params->getUmkreis());
        $url="https://" .
            $this->host . "/query/api/portal/v1/MatchingServiceEndpoint.php?wp=1&portalId=" .
            $this->portalId .
            "&accessKey=" . $this->accessKey;
		if($umkreis>0) $url.="&umkreis=".$umkreis;
        foreach(FreinetPortalKriterium::CRITERIAS as $criteriaName)
        {
            if($criteriaName=='angebotplzs')
            {
            	$plzs=trim(implode(',', $params->getCriterias()[$criteriaName]));
                if($plzs!='') $url.='&plz=' . $plzs;
                continue;
            }

			$criterias=trim(implode(',', $params->getCriterias()[$criteriaName]));
			if(is_string($criterias) && $criterias!=0 && $criterias!='') $url.='&' . $criteriaName . '=' . $criterias;
        }
        if($limit>self::LOWER_LIMIT||$limit<=self::UPPER_LIMIT)
        {
            $url.="&limit=" . $limit;
        }
        if($params->getPage())
        {
            $url.="&page=" . intval($params->getPage());
        }
        if($params->getProjektAusschlussListe() && $params->getProjektAusschlussListe()>1) $url.="&project_id_ex=" . esc_html($params->getProjektAusschlussListe());
        if($params->getProjektListe() && $params->getProjektListe()>1) $url.="&project_id_inc=" . esc_html($params->getProjektListe());
        if($params->getSuchmodus()) $url.="&suchmodus=" . $params->getSuchmodus();
        if($params->getSuchbegriff()) $url.="&suchbegriff=" . urlencode($params->getSuchbegriff());
        freinet_portal_debug($url, "search()", __FILE__, __LINE__);
        $freinetClient=new FreinetPortalSimpleHttpClient($url);
        $resultData=$freinetClient->get();
        return FreinetPortalSearchResult::fromXmlString($resultData);
    }

    /**
     * @param $offerId
     * @return FreinetPortalAngebotDetail
     * @throws ErrorException
     */
    function loadOffer($offerId)
    {
        $freinetClient=new FreinetPortalSimpleHttpClient(
            "https://" . $this->host . "/query/api/portal/v1/OfferServiceEndpoint.php?wp=1&portalId=" . $this->portalId .
            "&accessKey=" . $this->accessKey .
            "&offerId=" . $offerId
        );
        $result=$freinetClient->get();
        $angebotXmlData=new SimpleXMLElement($result);

        // freinet_portal_print_a(freinet_portal_object2array($angebotXmlData)); // unkommentieren, um alle Inhalte zu sehen

        $freinetAngebot=new FreinetPortalAngebotDetail(
            $angebotXmlData
        );
        return $freinetAngebot;
    }

    /**
     * Diese Funktion soll die einzelnen getter der MatchingKategorien ersetzen,
     * also anstatt
     * getZielgruppen
     * getArbeitweise
     * etc.
     * @param $matching_kriterium
     * @return array
     */
    private function getMatchingKategorie($arr_criterias, $matching_kriterium)
    {
        if(empty($arr_criterias)) return array();
        return $this->xmlToArray($arr_criterias, $matching_kriterium);
    }

    // Wenn function getMatchingKategorie() überall funktioniert, dann sind die folgenden Funktionen zu den Kategorien eigentlich obsolet
    private function getAngebotPlzs()
    {
        return $this->xmlToArray($this->cachedCriterias->angebotplzs[0]);
    }

    private function getUmkreise()
    {
        return array(2, 5, 10, 20);
    }

	/**
	 * @param $suchkonfigurationsId
	 *
	 * @throws ErrorException
	 */
    private function getCriterias($suchkonfigurationsId)
    {
        $url="https://" . $this->host . "/query/api/portal/v1/CriteriaServiceEndpoint.php?wp=1&portalId=" . $this->portalId . "&accessKey=" . $this->accessKey;
		if(get_option(FreinetPortalSettings::criteria_service_endpoint_combine_criterias($suchkonfigurationsId))==1) $url.="&combine_criterias=1";

        freinet_portal_debug($url, "getCriterias()", __LINE__, __FILE__);
        $freinetClient=new FreinetPortalSimpleHttpClient($url);
        $criterias=$freinetClient->get();
        if(!empty($criterias))
        {
            $this->cachedCriterias=new SimpleXMLElement($criterias);
        }
    }

    /**
     * @param $xmlElement
     * @return array
     */
    private function xmlToArray($xmlElement)
    {
        // Wenn $xmlElement, dann geben wir ein leeres Array zurück
        if(empty($xmlElement)) return array();

        $values=[];
        foreach($xmlElement as $value)
        {
            $values[$value[0]["id"]->__toString()]=$value->beschreibung[0]->__toString();
        }
        return $values;
    }

    /**
     * @return bool
     */
    private function criteriasNotLoaded()
    {
        return $this->cachedCriterias==null;
    }
}