<?php
// Sicherheitscheck, ob diese Datei im Wordpresscontext läuft. Ansonsten wird die Verarbeitung abgebrochen.
defined('ABSPATH') or die;

class FreinetPortalFormPagingRenderer extends FreinetPortalAbstractFormRenderer
{
    private $total;
    private $limit;
    private $currentPage;
    private $pagingEnabled;

    const EMPTY_PAGE_BAR = "";
    const FIRST_PAGE = 1;
    const FIRST_PAGE_TEXT = "&laquo;";
    const LAST_PAGE_TEXT = "&raquo;";
    const PREV_PAGE_TEXT = "&lsaquo;";
    const NEXT_PAGE_TEXT = "&rsaquo;";

    public function __construct($total, $limit, $currentPage, $pagingEnabled = false)
    {
        $this->total = $total;
        $this->limit = intval($limit);
        $this->setCurrentPage(intval($currentPage));
        $this->pagingEnabled = $pagingEnabled;
    }


    public function render()
    {
        return $this->pagingEnabled ? $this->renderPagingRow() : FreinetPortalFormPagingRenderer::EMPTY_PAGE_BAR;
    }

    private function displayStart()
    {
        return $this->calculateOffset() + 1;
    }

    private function displayEnd()
    {
        return min(($this->calculateOffset() +$this->limit),$this->total);
    }

    private function nextLink()
    {
        $numberOfPages = $this->calculateNumberOfPages();
        if($this->getCurrentPage() >= $numberOfPages)
        {
            return $this->createLinkForPage($numberOfPages);
        }
        elseif ($this->getCurrentPage() < self::FIRST_PAGE)
        {
            return $this->createLinkForPage(self::FIRST_PAGE);
        }
        return $this->createLinkForPage($this->getCurrentPage() + self::FIRST_PAGE);
    }

    private function prevLink()
    {
        $numberOfPages = $this->calculateNumberOfPages();
        if ($this->getCurrentPage() > $numberOfPages)
        {
            $this->createLinkForPage($numberOfPages);
        }
        elseif ($this->getCurrentPage() <= self::FIRST_PAGE)
        {
            $this->createLinkForPage(self::FIRST_PAGE);
        }
        return $this->createLinkForPage($this->getCurrentPage() - 1);
    }

    private function getLimit()
    {
        return $this->limit;
    }

    private function calculateNumberOfPages()
    {
        return ceil($this->total / $this->getLimit());
    }

    private function getCurrentPage()
    {
        if ($this->currentPage < self::FIRST_PAGE)
        {
            return self::FIRST_PAGE;
        }
        return $this->currentPage;
    }

    private function setCurrentPage($currentPage)
    {
        $this->currentPage = $currentPage;

    }

    private function calculateOffset()
    {
        $offset = ($this->getCurrentPage() - self::FIRST_PAGE) * $this->limit;
        if ($offset < 0) $offset = 0;
        return $offset;
    }

    private function displayFirst()
    {
        if ($this->getCurrentPage() > self::FIRST_PAGE)
        {
            return '<a class="button" href="' . add_query_arg(array('freinetSearchData[' . FREINET_PORTAL_URL_PARAMS['ergebnis_page'] . ']' => "1")) . '">' . self::FIRST_PAGE_TEXT . '</a> ';
        }
        return '<span class="button disabled">' . self::FIRST_PAGE_TEXT . '</span>';
    }

    private function displayLast()
    {
        if ($this->getCurrentPage() < $this->calculateNumberOfPages())
        {
            return '<a class="button" href="' . add_query_arg(array('freinetSearchData[' . FREINET_PORTAL_URL_PARAMS['ergebnis_page'] . ']' => $this->calculateNumberOfPages())) . '">' . self::LAST_PAGE_TEXT . '</a> ';
        }
        return '<span class="button disabled">' . self::LAST_PAGE_TEXT .'</span>';
    }

    private function displayPrev()
    {
        if ($this->getCurrentPage() > self::FIRST_PAGE)
        {
            return '<a class="button" href="' . $this->prevLink() . '">' . self::PREV_PAGE_TEXT . '</a> ';
        }
        return '<span class="button disabled">' . self::PREV_PAGE_TEXT . '</span>';
    }

    private function displayNext()
    {
        if ($this->getCurrentPage() < $this->calculateNumberOfPages())
        {
            return '<a class="button" href="' . $this->nextLink() . '">' . self::NEXT_PAGE_TEXT . '</a>';
        }
        return '<span class="button disabled">' . self::NEXT_PAGE_TEXT . '</span>';
    }

    private function createLinkForPage($page)
    {
        return esc_url_raw(add_query_arg(array('freinetSearchData[' . FREINET_PORTAL_URL_PARAMS['ergebnis_page'] . ']' => $page)));
    }

    /**
     * @return string
     */
    private function renderPagingRow()
    {
        $output = '<div id="paging" class="paging_container">';
        $output .= $this->displayFirst() . " ";
        $output .= $this->displayPrev();
        $output .= '<span class="paging_text small_device" style="display: none">';
        $output .= '<span class="paging_page"><span title="Seite">' . $this->getCurrentPage() . '</span> / <span title="Anzahl aller Seiten">' . $this->calculateNumberOfPages() . '</span></span> ';
        $output .= '<span class="paging_show"> <span title="Treffer">(' . $this->total . ' Treffer)</span></span> ';
        $output .= '</span>';
        $output .= '<span class="paging_text big_device">';
        $output .= '<span class="paging_page">Seite ' . $this->getCurrentPage() . ' von ' . $this->calculateNumberOfPages() . '</span> ';
        $output .= '<span class="paging_show">, zeige ' . $this->displayStart() . ' - ' . $this->displayEnd() . ' von ' . $this->total . ' Treffern</span> ';
        $output .= '</span>';
        $output .= $this->displayNext() . " ";
        $output .= $this->displayLast();
        $output .= '</div>';
        return $output;
    }
}