<?php
// Sicherheitscheck, ob diese Datei im Wordpresscontext läuft. Ansonsten wird die Verarbeitung abgebrochen.
defined('ABSPATH') or die;

/**
 * Ermittelt welche Seite angezeigt werden soll im öffentlichen Bereich des Plugins. In dieser Klasse müssen
 * alle Seiten registriert werden mit einem eindeutigen Wert für den Parameter freinet_portal_wp_action
 */
class FreinetPortalPluginPublicPageDispatcher
{
    private $apiClient;
    private $freinetActionPageMapping;
    private $defaultPage;

    public function __construct($apiClient)
    {
        $this->apiClient=$apiClient;
        $this->defaultPage=new FreinetPortalSearchPage($this->apiClient);
        $this->freinetActionPageMapping['Suchen']=new FreinetPortalSearchResultPage($this->apiClient);
        $this->freinetActionPageMapping['angebot_anzeigen']=new FreinetPortalOfferDetailPage($this->apiClient);
    }

    function dispatch($shortcutAttributes=[])
    {
        ob_start(); // Sicherstellen, dass das Plugin sich an die im Artikel gewünschte Stelle einfügt
        try
        {
            $suchkonfigurationId=$shortcutAttributes['suchkonfiguration'];
            $this->validateSuchkonfiguration($suchkonfigurationId);
            $requestValidator=new FreinetPortalPluginIncomingRequestValidator($_REQUEST);
            $requestValidator->validate();
            $action=$_REQUEST['freinet_portal_wp_action'];
            if($this->freinetActionPageMapping[$action]!=null)
            {
                $this->freinetActionPageMapping[$action]->render($suchkonfigurationId);
            }
            else
            {
                $this->defaultPage->render($suchkonfigurationId);
            }
        } catch(Exception $e)
        {
            echo "Leider ist bei der Freinet-Portal-API-Plugin-Verarbeitung ein Fehler aufgetreten: " . $e->getMessage();
        }

        return ob_get_clean();
    }

    /**
     * CSS Datei einfügen
     */
    function registerStyles()
    {
    	// 2021-09-09 freinet-style in freinet-portal-style umbenannt, um Konflikt mit dem Plugin freinet_api_angebote zu umgehen
        if(is_file(plugin_dir_path(__FILE__) . 'suche/css/freinetstyle_CUSTOM.css'))
        {
            wp_register_style('freinet-portal-style', plugins_url('freinet_api_portale/suche/css/freinetstyle_CUSTOM.css'));
        }
        else
        {
            wp_register_style('freinet-portal-style', plugins_url(FREINET_PORTAL_STYLE_CSS));
        }
        wp_enqueue_style('freinet-portal-style');
    }

    /**
     * Kümmert sich um den Redirect auf eine GET-URL nachdem die Suche ausgeführt wurde. Dadurch kann der Nutzer
     * auf seinem Suchergebnis auch problemlos die Suche per Aktualisierung der Seite ausführen oder einen Bookmark
     * auf eine Suche setzen.
     */
    function handlePost()
    {
        if($_SERVER['REQUEST_METHOD']=="POST"&&$_POST['freinet_portal_wp_action']=='Suchen')
        {
            $freinetSearchData=$_POST['freinetSearchData'];
            $urlQueryParams=array();
            foreach($freinetSearchData as $key=>$value)
            {
                if(isset($value))
                {
                    if(is_string($value)&&strlen($value)!=0)
                    {
                        $urlQueryParams["freinetSearchData[" . $key . "]"]=$value;
                    }
                    if(is_array($value))
                    {
                        $urlQueryParams["freinetSearchData[" . $key . "]"]=$value;
                    }
                }

            }
            $urlQueryParams['freinet_portal_wp_action']="Suchen";
            $url=remove_query_arg("freinetSearchData");
            $url=add_query_arg($urlQueryParams, $url);
            wp_redirect(esc_url_raw($url));
            exit; // Exit ist Pflicht nach dem Redirect, siehe https://developer.wordpress.org/reference/functions/wp_redirect/
        }
    }

    /**
     * @param $suchkonfiguration
     * @throws ErrorException
     */
    private function validateSuchkonfiguration($suchkonfiguration)
    {
        if(!preg_match('/^\d+$/', $suchkonfiguration))
        {
            throw new ErrorException("Leider wurde die Suchkonfiguration nicht gefunden. Siehe ›Informationen zum Plugin‹ im Plugin-Setup");
        }
        $portalSuchkonfigurationen=explode(',', get_option('freinet_portal_instanz_liste'));
        if(!in_array($suchkonfiguration, $portalSuchkonfigurationen))
        {
            throw new ErrorException("Leider wurde die Suchkonfiguration nicht gefunden. Siehe ›Informationen zum Plugin‹ im Plugin-Setup");
        }
    }
}