<?php

class FreinetPortalImageTagRenderer
{
	private $imageUrl;
	private $itemProp;
	private $itemInfo; // 2020-10-26

	/**
	 * ImageTagRenderer renders an image tag for the plugin
	 *
	 * @param $imageUrl string image you want to show
	 */
	public function __construct($imageUrl)
	{
		$this->imageUrl=$imageUrl;
	}

	public function render()
	{
		$imageTag='<img';

		// Eine Klasse zum Logo hinzufügen, um gezielt via CSS ansprechen zu können
		if(isset($this->itemInfo->class) && $this->itemInfo->class!='')
		{
			$imageTag.=' class="'.$this->itemInfo->class.'"';
		}
		elseif(strstr($this->imageUrl, 'avatar')) $imageTag.=' class="ImageAvatar"';
		elseif(strstr($this->imageUrl, 'logo')) $imageTag.=' class="ImageLogo"';

		$imageTag.=' src="'.$this->imageUrl.'"';
		if(!empty($this->itemProp))
		{
			$imageTag.=' itemprop="'.$this->itemProp.'"';
		}
		if(!empty($this->itemInfo))
		{
			$imageTag.=' alt="'.$this->itemInfo->medium_title.'"'; // alt-Tag mit Medium-Title füllen

			if($this->itemInfo->medium_beschreibung!='') $imageTag.=' title="'.htmlspecialchars($this->itemInfo->medium_beschreibung).'"';
			// if($this->itemInfo->medium_info!='') $imageTag.=' data-info="'.htmlspecialchars($this->itemInfo->medium_info).'"'; // Memofeld! Nur nach Rücksprache nutzen
			if($this->itemInfo->medium_aufgenommen_von!='') $imageTag.=' data-autor="'.htmlspecialchars($this->itemInfo->medium_aufgenommen_von).'"';
			if($this->itemInfo->medium_quelle!='') $imageTag.=' data-quelle="'.htmlspecialchars($this->itemInfo->medium_quelle).'"';
		}
		else
		{
			// alt-Tag, falls bisher nicht erstellt.
			$imageTag.=' alt="';
			if(strstr($this->imageUrl, 'avatar'))
			{
				$imageTag.='Avatar';
			}
			elseif(strstr($this->imageUrl, 'logo')) $imageTag.='Logo';
			$imageTag.='"';
		}

		$imageTag.='>';
		return $imageTag;
	}

	public static function fromUrl($imageUrl, $itemProp='', $itemInfo=array())
	{
		$image=new FreinetPortalImageTagRenderer($imageUrl);
		if(!empty($itemProp))
		{
			$image->setItemProp($itemProp);
		}
		if(!empty($itemInfo))
		{
			$image->setItemInfo($itemInfo);
		}
		return $image->render();
	}

	/**
	 * @param string $itemProp will be added as imageprop tag
	 */
	public function setItemProp($itemProp)
	{
		$this->itemProp=$itemProp;
	}

	/**
	 * @param string $itemInfo will be added as some imgage tags
	 */
	public function setItemInfo($itemInfo)
	{
		$this->itemInfo=$itemInfo;
	}

}