<?php
/*
 * Plugin Name: Freinet Portal Plugin
 * Description: Ein Freinet Plugin welches über die API im Hintergrund Angebote *eines* Portals laden und anzeigen kann
 * Author: FreiNet-Online
 * License: GPLv2
 * Version: 1.0-SNAPSHOT
 */

// Sicherheitscheck, ob diese Datei im Wordpresscontext läuft. Ansonsten wird die Verarbeitung abgebrochen.
defined('ABSPATH') or die;

// Warnung! Wenn dieser Parameter auf true gesetzt wird, wird der AccessKey in der HTML-Seitenausgabe
// angezeigt. Benutzen Sie dieses Feature nur lokal
define('FREINET_PORTAL_WP_DEBUG', false);
error_reporting('E_ALL');
ini_set('display_errors',1);

// Debugmodus für das Plugin aktivieren

// Prefix für die Optionen die in Wordpress für die Matchingkriterien gespeichert werden sollen
const FREINET_PORTAL_WP_OPTIONS_PREFIX = 'freinet_portal_1_matchingcriteria_use_';

// Auflistung aller Matchingkriterien und der Einstellung die in der wp_options Tabelle gespeichert werden
// Freinet bietet NOCH mehr Kategorien (siehe https://gitlab.com/freinet-online/freinet-wp-plugin/snippets/1735403 )
// aber dies sind die Kategorien, die die API derzeit liefern kann.
const FREINET_PORTAL_WP_OPTIONS = array(
    'angebotplzs' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'angebotplzs', // added 2021-09-08
    'arbeitsweisen' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'arbeitsweisen',
    'zielgruppen' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'zielgruppen',
    'ziel2gruppen' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'ziel2gruppen',
    'handlungsfelder' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'handlungsfelder',
    'handlungs2felder' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'handlungs2felder',
    'kenntnisse' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'kenntnisse',
    'globalbereiche' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'globalbereiche',
    'sprachen' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'sprachen',
    'stadtteile' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'stadtteile',
    'umgebung' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'umgebung',
    'zeitspenden' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'zeitspenden',
    'mtffa1' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa1',
    'mtffa2' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa2',
    'mtffa3' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa3',
    'mtffa4' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa4',
    'mtffa5' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa5',
    'mtffa6' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'mtffa6',
    'ehrenamttyp' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'ehrenamttyp',
    'portalmatrix1' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'portalmatrix1',
    'portalmatrix2' => FREINET_PORTAL_WP_OPTIONS_PREFIX . 'portalmatrix2'
);

const FREINET_PORTAL_URL_PARAMS = array(
	'ergebnis_page' => 'freinet_portal_result_page'
);

const FREINET_PORTAL_STYLE_CSS = 'freinet_api_portale/suche/css/freinetstyle.css';

require_once(plugin_dir_path(__FILE__) . 'FreinetPortalAdminPage.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalPluginIncomingRequestValidator.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalSearchResult.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalSettings.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalClasses.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalAbstractFormRenderer.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalPluginPublicPageDispatcher.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormSelectBoxRenderer.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormCheckBoxRenderer.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormInputTextRenderer.php'); // 2021-09-08
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormCheckButtonRenderer.php'); // 2021-09-08
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormSelectCheckBoxesRenderer.php'); // 2021-09-08
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalFormPagingRenderer.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalSimpleHttpClient.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalSearchParams.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalApiClient.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalAngebotListe.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalAngebotDetail.php');
require_once(plugin_dir_path(__FILE__) . 'FreinetPortalKriterium.php');

// -- [ Konfiguration von Wordpress und der beteiligten Komponenten ] --------------------------------------------------
$freinetPortalApiClient = new FreinetPortalApiClient(
    get_option('freinet_portal_api_key'),
    get_option('freinet_portal_portal_id'),
    get_option('freinet_portal_api_host')
);

// Registrierung der Adminseite
$freinetPortalAdminPage = new FreinetPortalAdminPage();
$freinetPortalAdminPage->register();

$freinetPortalPublicPageDispatcher = new FreinetPortalPluginPublicPageDispatcher($freinetPortalApiClient);

// Registrierung des Plugins an den entsprechenden hooks in Wordpress
add_shortcode('freinet_portal_api_portale', array($freinetPortalPublicPageDispatcher, 'dispatch'));
add_action('wp_enqueue_scripts', array($freinetPortalPublicPageDispatcher, 'registerStyles'));
add_action('wp_loaded', array($freinetPortalPublicPageDispatcher, 'handlePost'))

// -- [ Pluginimplementierung ] ----------------------------------------------------------------------------------------

// JR Klassen und Funktionen nach FreinetPortalClasses.php verschoben, weil in php Version < 7 die Klassen noch vor FreinetPortalPluginSelectBoxRenderer.php bekannt sein müssen

?>